@@ -135,6 +135,16 @@ checkrp <- function (r, p){
 ##' @references see the literature in \code{citation ("softclassval")}
 ##' @export
 ##' @include softclassval.R
+##' @examples
+##'
+##' ref <- softclassval:::ref
+##' ref
+##'
+##' pred <- softclassval:::pred
+##' pred
+##'
+##' ## Single elements or diagonal of confusion matrix
+##' confusion (r = ref, p = pred)
 confusion <- function (r = stop ("missing reference"), p = stop ("missing prediction"),
                        groups = NULL,
                        operator = "prd",
@@ -147,11 +157,60 @@ confusion <- function (r = stop ("missing reference"), p = stop ("missing predic
 
   drop1d (res, drop = drop)
 }
-.test (confusion) <- function (){
-  
+## testing by .test (sens)
+
+
+##' \code{confmat} calculated the soft confusion matrix
+##' 
+##' @rdname performance
+##' @export
+##' @examples
+##'
+##' ## complete confusion matrix
+##' cm <- confmat (r = softclassval:::ref, p = pred) [1,,]
+##' cm
+##' 
+##' ## Sensitivity-Specificity matrix:
+##' cm / rowSums (cm)
+##'
+##' ## Matrix with predictive values:
+##' cm / rep (colSums (cm), each = nrow (cm))
+confmat <- function (r = stop ("missing reference"), p = stop ("missing prediction"), ...){
+	rx <- slice (r, j = rep (seq_len (ncol (r)), ncol (p)), drop = FALSE)
+	colnames (rx) <- NULL
+	
+	px <- slice (p, j = rep (seq_len (ncol (p)), each = ncol (r)), drop = FALSE)
+	colnames (px) <- NULL
+	
+	cm <- confusion (r = rx, p = px, ...)
+	d <- dim (cm)
+	dim (cm) <- c (d [1], ncol (r), ncol (p), d [- (1 : 2)])
+
+	dn <- dimnames (p)
+	if (is.null (dn)) dn <- rep (list (NULL), ndim (p))
+	dn <- c (list (rownames (cm)), list (r = colnames (r)), dn [- 1L])
+	names (dn) [3L] <- "p"
+	dimnames (cm) <- dn
+	cm
 }
-##TODO tests
-##TODO test grouping
+.test (confmat) <- function (){
+  cm <- confmat (r = ref, p = pred)[1,,]
+  warn <- options(warn = -1)$warn
+  on.exit (options (warn = warn))
+  for (r in colnames (ref))
+    for (p in colnames (pred))
+      checkEqualsNumeric (cm [r, p], confusion (r = ref [, r], p = pred [, p]))
+  options (warn = warn)
+  
+  ## one sample only
+  checkEquals (confmat (r = ref[1,,drop = FALSE], p = pred[1,,drop = FALSE])[1,,],
+               structure(c(1, 0, 0, 0, 0, 0, 0, 0, 0),
+                         .Dim = c(3L, 3L),
+                         .Dimnames = structure(list(r = c("A", "B", "C"), p = c("a", "b", "c")),
+                           .Names = c("r", "p")))
+               )
+}
+
 
 ##' @param eps limit below which denominator is considered 0
 ##' @param op.dev does the operator measure deviation?
@@ -159,6 +218,10 @@ confusion <- function (r = stop ("missing reference"), p = stop ("missing predic
 ##' here. See the example.
 ##' @rdname performance
 ##' @export
+##' @examples
+##'
+##' ## sensitivities
+##' sens (r = ref, p = pred)
 sens <- function (r = stop ("missing reference"), p = stop ("missing prediction"), groups = NULL,
                   operator = "prd",
                   op.dev = dev (match.fun (operator)),
@@ -273,12 +336,20 @@ sens <- function (r = stop ("missing reference"), p = stop ("missing prediction"
 ##' @param ... handed to \code{sens}
 ##' @rdname performance
 ##' @export 
+##' @examples
+##'
+##' ## specificities
+##' spec (r = ref, p = pred)
 spec <- function (r = stop ("missing reference"), p = stop ("missing prediction"), ...){
   sens (r = 1 - r, p = 1 - p, ...)
 }
 
 ##' @rdname performance
-##' @export 
+##' @export
+##' @examples
+##'
+##' ## predictive values
+##' ppv (r = ref, p = pred)
 ppv <- function (r = stop ("missing reference"), p = stop ("missing prediction"), ...,
                  .checked = FALSE){
   if (! .checked)
@@ -291,7 +362,9 @@ ppv <- function (r = stop ("missing reference"), p = stop ("missing prediction")
 }
 
 ##' @rdname performance
-##' @export 
+##' @export
+##' @examples
+##' npv (r = ref, p = pred)
 npv <- function (r = stop ("missing reference"), p = stop ("missing prediction"), ...,
                  .checked = FALSE){
   if (! .checked)
